import React, { Component } from 'react';
import {
    StyleSheet,
    View} from 'react-native';
import Video from 'react-native-video';
import MediaControls, { PLAYER_STATES } from 'react-native-media-controls';


class VideoController extends Component {

    constructor(props) {
        super(props);
        this.state = {
            currentTime: 0,
            duration: 0,
            isFullScreen: false,
            isLoading: true,
            paused: this.props.paused,
            playerState: PLAYER_STATES.PLAYING,
        };
    }

    onSeek = seek => {
        this.videoPlayer.seek(seek);
    };

    onPaused = playerState => {
        this.setState({
            paused: !this.state.paused,
            playerState,
        });
    };

    onReplay = () => {
        this.setState({ playerState: PLAYER_STATES.PLAYING });
        this.videoPlayer.seek(0);
    };

    onProgress = data => {
        const { isLoading, playerState } = this.state;
        if (!isLoading && playerState !== PLAYER_STATES.ENDED) {
            this.setState({ currentTime: data.currentTime });
        }
    };

    onFullScreen = () => {
        console.log("asd");
    };

    onLoad = data => this.setState({ duration: data.duration, isLoading: false });

    onLoadStart = data => {
        this.setState({ isLoading: true });
    }

    onEnd = () => this.setState({ playerState: PLAYER_STATES.ENDED });

    onSeeking = currentTime => this.setState({ currentTime });
    render() {


        if (!this.props.src)
            return <View style={this.style} />

        console.log("rendered");
        console.log(this.props);

        if (!!this.props.controls) {
            return (<View style={{width: 100, height: 100}}>
                <Video
                    onEnd={this.onEnd}
                    onLoad={this.onLoad}
                    onLoadStart={this.onLoadStart}
                    onProgress={this.onProgress}
                    paused={this.state.paused}
                    ref={videoPlayer => (this.videoPlayer = videoPlayer)}
                    resizeMode="cover"
                    source={{ uri: this.props.src }}
                    style={styles.mediaPlayer}
                    volume={1.0}
                />
                <MediaControls
                    duration={this.state.duration}
                    isLoading={this.state.isLoading}
                    onFullScreen={this.onFullScreen}
                    mainColor="#A9A9A9"
                    onPaused={this.onPaused}
                    onReplay={this.onReplay}
                    onSeek={this.onSeek}
                    onSeeking={this.onSeeking}
                    playerState={this.state.playerState}
                    progress={this.state.currentTime}
                />
            </View>);
        }
        else
            return (<Video  source={{uri: this.props.src}} paused={this.props.paused} repeat={!!this.props.repeat} style={this.props.style} volume={0.0} />);
    }
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
    },
    mediaPlayer: {
        position: 'absolute',
        top: 0,
        left: 0,
        bottom: 0,
        right: 0,
        backgroundColor: 'black',
    },
});

module.exports = VideoController
