import React, { Component } from 'react';
import { View, Text, ScrollView, StyleSheet, ImageBackground } from 'react-native';
import { viewConverter } from './utils/index';

import { storeLoadedFonts, storeTheme } from './utils/font-handler';
import RNFetchBlob from 'rn-fetch-blob';
import { loadFonts } from 'react-native-dynamic-fonts';

export default class Incito extends Component {

    constructor(props) {
        super(props);
        this.state = { isLoading: true, width:'50%'}
        let { options } = this.props;
        if (options == null)
            throw "options is not defined";

        if (options.incito == null)
            throw "options does not contain incito";

        this.data = options.incito;
        if (this.data.root_view == null)
            throw "options incito does not contain root_view";

    }

    componentWillMount() {
        this._loadFonts(this.data.font_assets);
    }

    _doneLoadíng() {
        storeTheme(this.data.theme);
        this.setState({
            isLoading: false
        });

    }

    _requestFonts(fonts) {
        let finishedThreadCounter = 0;
        self = this;

        fonts.forEach(value => {
            RNFetchBlob.fetch('GET', value.url)
                .then((res) => {

                if(res.info().status !== 200)
                    return;

                    value.data = res.base64();
                    if(finishedThreadCounter++ === fonts.length - 1) {
                        loadFonts(fonts, false).then(function(names) {
                            storeLoadedFonts(fonts, names);
                            self._doneLoadíng();
                        });
                    }
            })
        })
    }

    _loadFonts(fonts) {
        let validFonts = []
        if (fonts == null || fonts.length === 0) {
            this._doneLoadíng();
            return;
        }

        let entries = Object.entries(fonts);


        entries.forEach(([key, value]) => {
                if (Array.isArray(value.src)) {
                    let validUrl = value.src.find(function (font) {
                        return font.length === 2 && (font[1].endsWith(".otf") || font[1].endsWith(".ttf"))
                    })

                    if (validUrl)
                        validFonts.push({name: key, type: validUrl[1].substring(validUrl[1].length - 3), url: validUrl[1]});
                }
            }
        );
        this._requestFonts(validFonts)
    }

    _render(attr) {
        let childViews = this._proccessChildViews(attr);
        return viewConverter(attr, childViews);
    }

    _proccessChildViews(attr, rendered_child_views = []) {
       if (!Array.isArray(attr.child_views))
           return [];

       self = this;
       attr.child_views.forEach(function(child_view){
           if (child_view.view_name === 'FragView')
                self._proccessChildViews(child_view, rendered_child_views);
           else
               rendered_child_views.push(self._render(child_view));
       });
       return rendered_child_views;
    }

  render() {
      if(this.state.isLoading)
          return (<Text>Fonts are not loaded</Text>)

      return (<ScrollView>
          {this._render(this.data.root_view).render()}
      </ScrollView>);
  }
}

