import React, { Component } from 'react';
import {
  Platform,
  StyleSheet,
  Text,
  View,
    Alert,
    ImageBackground
} from 'react-native';
import IncitoView from './view';
import { defaultFont, loadedFont, defaultTextColor, defaultMarginMultiplier } from '../utils/font-handler';
import uniqueId from '../utils/id-assigner';

function renderText(attr) {
    if(attr.text){
        let text = attr.text;

        if(attr.text_all_caps)
            text = text.toUpperCase();

        return text;
    }
    return "";
}


function textShadow(style, attr) {
    if (attr.text_shadow_color){
        let dx = typeof attr.text_shadow_dx === 'number' ? attr.text_shadow_dx : 0,
            dy = typeof attr.text_shadow_dy === 'number' ? attr.text_shadow_dy : 0,
            radius = typeof attr.text_shadow_radius === 'number' ? attr.text_shadow_radius : 0,
            color = attr.text_shadow_color;
        style.textShadowColor = color;
        style.textShadowRadius = radius;
        style.textShadowOffset = {width: dx, height: dy};
    }
}

function textStyle(attr, textStyle){
    if(attr.text_size)
        textStyle.fontSize = attr.text_size;
    else
        textStyle.fontSize = 14;

    if(attr.line_spacing_multiplier)
        textStyle.lineHeight = textStyle.fontSize * attr.line_spacing_multiplier;
    else if(defaultMarginMultiplier() != null) {
        textStyle.lineHeight = textStyle.fontSize * defaultMarginMultiplier();
    }

    if(attr.text_color)
        textStyle.color = attr.text_color;
    else if(defaultTextColor() != null)
        textStyle.color = defaultTextColor();


    let textStyles = (attr.text_style || '').split('|')

    if(textStyles.indexOf('bold') !== -1)
        textStyle.fontWeight = 'bold';

    if(textStyles.indexOf('italic') !== -1)
        textStyle.fontStyle = 'italic';

    if(attr.text_alignment)
        textStyle.textAlign = attr.text_alignment

    if (Array.isArray(attr.font_family)) {
        let loadedFontName = attr.font_family.find(function (font) {
            return loadedFont(font) != null;
        });
        if (loadedFontName)
            textStyle.fontFamily = loadedFontName;
    }

    if (textStyle.fontFamily == null && defaultFont() != null)
        textStyle.fontFamily = defaultFont();

    textShadow(textStyle, attr);
    return textStyle;
}

class IncitoTextView extends IncitoView {

    customStyle(style) {
        return textStyle(this.attributes(), style);
    }


    numberOfLines(attr){
        let numberOfLines = 0;
        if(attr.single_line)
            numberOfLines = 1;
        else if(attr.max_lines)
            numberOfLines = attr.max_lines;
        return numberOfLines;
    }

    createElement() {
        let numberOfLines = this.numberOfLines(this.attributes());
        return (<Text numberOfElements={numberOfLines === 0 ? {} : numberOfLines} style={this.style}>{renderText(this.attributes())}</Text>);
    }
}

module.exports = IncitoTextView